Tutorials
=========

This section contains a series of tutorials on how to use and get the most out
of ``LEGWORK``. We are working to add more tutorials over time and are very open
to feedback!

The fastest way to get started is our quickstart tutorial:

.. raw:: html

    <div style="max-width: 400px; margin: 30px auto;">
        <div class="toms-nav-box" data-href="notebooks/Quickstart.html">Quickstart</div>
    </div>

For more in-depth details and examples, check out our other tutorials:

.. raw:: html

    <div class="toms-nav-container" style="margin-bottom:30px;">
        <div class="box" data-href="notebooks/Source.html">Using the Source Class</div>
        <div class="box" data-href="notebooks/Strains.html">Computing Gravitational Wave Strains</div>
        <div class="box" data-href="notebooks/Evolution.html">Binary Evolution</div>
        <div class="box" data-href="notebooks/Visualisation.html">Visualisation</div>
    </div>

    <div style="max-width: 300px; margin: 40px auto 50px auto;">
        <div class="toms-nav-box" data-href="notebooks/Units.html">Units in LEGWORK</div>
    </div>

.. toctree::
    :titlesonly:
    :maxdepth: 1
    :hidden:

    Quickstart <notebooks/Quickstart.ipynb>
    Using the Source Class <notebooks/Source.ipynb>
    Computing Gravitational Wave Strains <notebooks/Strains.ipynb>
    Binary Evolution <notebooks/Evolution.ipynb>
    Visualisation <notebooks/Visualisation.ipynb>
    Understanding units in LEGWORK <notebooks/Units.ipynb>
